from datetime import datetime


def 日期转星期几(日期字符串: str) -> str:
    """把日期字符串转换成星期几。

    功能说明:
        - 这个函数用于判断某个日期是星期几。
        - 输入内容只需要写日期，格式为 ``YYYY-MM-DD``。
        - 返回结果是 ``星期一`` 到 ``星期日`` 这样的中文字符串。
        - 输入格式不正确时，函数返回空字符串 ``""``。

    Args:
        日期字符串: 日期字符串。

    Returns:
        成功时返回中文星期；失败时返回空字符串 ``""``。
    """
    try:
        日期对象 = datetime.strptime(日期字符串.strip(), "%Y-%m-%d")
        星期列表 = ["星期一", "星期二", "星期三", "星期四", "星期五", "星期六", "星期日"]
        return 星期列表[日期对象.weekday()]
    except Exception:
        return ""


if __name__ == "__main__":
    print("===== 示例1：普通日期转星期几 =====")
    print("结果:", 日期转星期几("2026-03-20"))

    print("\n===== 示例2：周末日期 =====")
    print("结果:", 日期转星期几("2026-03-22"))

    print("\n===== 示例3：闰年日期 =====")
    print("结果:", 日期转星期几("2024-02-29"))

    print("\n===== 示例4：输入错误格式 =====")
    print("结果:", 日期转星期几("2026/03/20"))

    print("\n===== 示例5：输入不存在的日期 =====")
    print("结果:", 日期转星期几("2026-02-30"))

    print("\n===== 示例6：应用场景-把活动日期显示成“日期+星期” =====")
    日期 = "2026-04-15"
    print("结果:", 日期, 日期转星期几(日期))
