from datetime import datetime


def 取本月第几天(时间字符串: str | None = None) -> int | None:
    """返回指定日期是本月的第几天。

    功能说明:
        - 这个函数用于判断某个日期在本月里排第几天。
        - 支持传入日期，也支持传入完整时间。
        - 不传参数时，默认使用今天。
        - 输入格式不正确时，函数返回 ``None``。

    Args:
        时间字符串: ``YYYY-MM-DD`` 或 ``YYYY-MM-DD HH:MM:SS`` 格式的日期时间字符串。

    Returns:
        成功时返回本月第几天；失败时返回 ``None``。
    """
    try:
        if 时间字符串 is None:
            return datetime.now().day
        时间字符串 = 时间字符串.strip()
        if len(时间字符串) == 10:
            return datetime.strptime(时间字符串, "%Y-%m-%d").day
        return datetime.strptime(时间字符串, "%Y-%m-%d %H:%M:%S").day
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：传入普通日期 =====")
    print("结果:", 取本月第几天("2026-03-20"))

    print("\n===== 示例2：传入月初日期 =====")
    print("结果:", 取本月第几天("2026-03-01"))

    print("\n===== 示例3：传入完整时间 =====")
    print("结果:", 取本月第几天("2026-03-20 10:30:45"))

    print("\n===== 示例4：不传参数 =====")
    print("结果:", 取本月第几天())

    print("\n===== 示例5：输入错误格式 =====")
    print("结果:", 取本月第几天("2026/03/20"))

    print("\n===== 示例6：应用场景-显示今天是本月第几天 =====")
    print("结果:", 取本月第几天())
