from datetime import datetime


def 是否周末(时间字符串: str | None = None) -> bool:
    """判断某个时间是不是周末。

    功能说明:
        - 这个函数用于判断某个日期是不是星期六或星期日。
        - 你可以传入完整时间字符串，也可以不传参数直接判断今天。
        - 周末指星期六和星期日。
        - 输入格式不正确时，函数返回 ``False``。

    Args:
        时间字符串: 要判断的时间字符串，格式为 ``YYYY-MM-DD HH:MM:SS``；不传时默认判断当前时间。

    Returns:
        是周末返回 ``True``，否则返回 ``False``。
    """
    try:
        if 时间字符串 is None:
            时间对象 = datetime.now()
        else:
            时间对象 = datetime.strptime(时间字符串.strip(), "%Y-%m-%d %H:%M:%S")
        return 时间对象.weekday() >= 5
    except Exception:
        return False


if __name__ == "__main__":
    print("===== 示例1：判断周六 =====")
    print("结果:", 是否周末("2026-03-21 10:00:00"))

    print("\n===== 示例2：判断周日 =====")
    print("结果:", 是否周末("2026-03-22 10:00:00"))

    print("\n===== 示例3：判断工作日 =====")
    print("结果:", 是否周末("2026-03-20 10:00:00"))

    print("\n===== 示例4：不传参数，判断今天 =====")
    print("结果:", 是否周末())

    print("\n===== 示例5：输入错误格式 =====")
    print("结果:", 是否周末("2026/03/21"))

    print("\n===== 示例6：应用场景-决定是否显示周末值班提示 =====")
    print("是否显示值班提示:", 是否周末("2026-03-22 09:00:00"))
