from typing import Any, Tuple


def 取极差(元组数据: Tuple[Any, ...]):
    """返回元组数值成员的极差。

    功能说明:
        - 这个函数用于返回元组数值成员的极差。
        - 常用于从元组中读取某个成员、某一段数据，或者计算出一个统计结果。
        - 如果当前数据不适合处理，函数会返回约定好的结果，方便新手直接判断这次是否成功取到值。

    Args:
        元组数据: 仅包含可比较数值的元组。

    Returns:
        成功时返回极差；失败时返回 ``None``。
    """
    try:
        if not isinstance(元组数据, tuple) or not 元组数据:
            return None
        return max(元组数据) - min(元组数据)
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：基础极差 =====")
    数据 = (10, 30, 20, 50)
    print("结果:", 取极差(数据))

    print("\n===== 示例2：包含负数 =====")
    数据 = (-5, 10, 20)
    print("结果:", 取极差(数据))

    print("\n===== 示例3：单成员元组 =====")
    数据 = (99,)
    print("结果:", 取极差(数据))

    print("\n===== 示例4：空元组 =====")
    数据 = ()
    print("结果:", 取极差(数据))

    print("\n===== 示例5：包含非数字 =====")
    数据 = (10, "20", 30)
    print("结果:", 取极差(数据))

    print("\n===== 示例6：应用场景-分析本周波动范围 =====")
    日销售额 = (1200, 1880, 1560, 2100, 1750)
    print("结果:", 取极差(日销售额))



