from typing import Any, Dict

def 确保为字典(数据: Any) -> Dict[str, Any]:
    """确保返回值为字典类型。

    功能说明:
        - 这个函数用于确保返回值为字典类型。
        - 它把字典里的常见操作单独封装好了，调用时不用自己反复写判断逻辑。
        - 当输入不符合要求时，函数会返回空字典或约定结果，避免程序因为异常中断。

    Args:
        数据: 任意类型的输入数据，来源可能不受信任。

    Returns:
        dict[str, Any]:
        - 成功：返回一个可用的字典对象（原始或新建）；
        - 兜底：返回空字典 {}。"""
    try:
        if isinstance(数据, dict):
            return 数据
        return {}
    except Exception:
        return {}


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    print("结果:", 确保为字典(数据))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    print("结果:", 确保为字典(数据))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    print("结果:", 确保为字典(数据))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    print("结果:", 确保为字典(数据))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    print("结果:", 确保为字典(数据))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    print("结果:", 确保为字典(数据))
    print("数据:", 数据)
