def 取某年开始时间(年份: int) -> str | None:
    """返回指定年份的开始时间。

    功能说明:
        - 这个函数用于直接拿到某一年的第一个时刻。
        - 传入年份后，函数会返回该年 1 月 1 日的 ``00:00:00``。
        - 如果年份不是整数或值不合法，函数返回 ``None``。

    Args:
        年份: 要查询的年份。

    Returns:
        成功时返回该年开始时间；失败时返回 ``None``。
    """
    try:
        年份 = int(年份)
        if 年份 <= 0:
            return None
        return f"{年份:04}-01-01 00:00:00"
    except Exception:
        return None


if __name__ == "__main__":
    print("===== 示例1：取 2026 年开始时间 =====")
    print("结果:", 取某年开始时间(2026))

    print("\n===== 示例2：传入字符串年份 =====")
    print("结果:", 取某年开始时间("2024"))

    print("\n===== 示例3：传入较早年份 =====")
    print("结果:", 取某年开始时间(1999))

    print("\n===== 示例4：传入 0 =====")
    print("结果:", 取某年开始时间(0))

    print("\n===== 示例5：传入非法内容 =====")
    print("结果:", 取某年开始时间("二零二六"))

    print("\n===== 示例6：应用场景-生成历史年度查询起始时间 =====")
    print("查询开始:", 取某年开始时间(2020))
