from typing import Any, Dict

def 删除空值键(数据: Dict[str, Any]) -> int:
    """删除字典中值为空的键，并返回删除数量。

    功能说明:
        - 这个函数用于删除字典中值为空的键，并返回删除数量。
        - 它把字典里的常见操作单独封装好了，调用时不用自己反复写判断逻辑。
        - 当输入不符合要求时，函数会返回约定好的兜底结果，避免程序因为异常中断。

    Args:
        数据 (dict): 需要清理的字典对象。

    Returns:
        int:
        - 成功：返回实际删除的键数量；
        - 失败：返回 0。"""
    try:
        if not isinstance(数据, dict):
            return 0

        待删除键列表 = [
            键
            for 键, 值 in 数据.items()
            if 值 is None or 值 == "" or 值 == [] or 值 == {}
        ]

        for 键 in 待删除键列表:
            del 数据[键]

        return len(待删除键列表)
    except Exception:
        return 0


if __name__ == "__main__":
    print("===== 示例1：基础用法 =====")
    数据 = {"名称": "zfx", "年龄": 18, "城市": "上海"}
    print("结果:", 删除空值键(数据))
    print("数据:", 数据)

    print("\n===== 示例2：常见变体 =====")
    数据 = {"name": "zfx", "phone": None, "items": [1, 2]}
    print("结果:", 删除空值键(数据))
    print("数据:", 数据)

    print("\n===== 示例3：边界情况 =====")
    数据 = {}
    print("结果:", 删除空值键(数据))
    print("数据:", 数据)

    print("\n===== 示例4：异常情况 =====")
    数据 = []
    print("结果:", 删除空值键(数据))
    print("数据:", 数据)

    print("\n===== 示例5：特殊值情况 =====")
    数据 = {"名称": "", "备注": None, "标签": []}
    print("结果:", 删除空值键(数据))
    print("数据:", 数据)

    print("\n===== 示例6：应用场景-整理业务字典 =====")
    数据 = {"订单号": "A001", "状态": "待发货", "数量": 3}
    print("结果:", 删除空值键(数据))
    print("数据:", 数据)
